"use strict";
/**
 * @fileoverview Add an attribute
 * @author Frédéric Maquin <fred@ephread.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------
/**
 * addAttribute - Add an attribute specified by the given rule to the given nodes.
 *
 * @param {object} rule  rule definition
 * @param {object} nodes nodes on which remove attributes
 */
function addAttribute(configurationRule, nodes) {
    const rule = configurationRule;
    for (const attribute of rule.attributes) {
        const attributeName = Object.keys(attribute)[0];
        const value = attribute[attributeName];
        if (rule.append) {
            nodes.forEach((path) => {
                const currentValue = path.attr(attributeName);
                let valueToSet = value;
                if (currentValue != null) {
                    valueToSet = `${currentValue.value()} ${valueToSet}`;
                }
                path.attr({ [attributeName]: valueToSet });
            });
        }
        else {
            nodes.forEach((path) => path.attr({ [attributeName]: value }));
        }
    }
}
exports.addAttribute = addAttribute;
//# sourceMappingURL=addAttribute.js.map