"use strict";
/**
 * @fileoverview Copy an attribute
 * @author Frédéric Maquin <fred@ephread.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------
/**
 * copyAttribute - Copy the value of an attribute to a new attribute, specified by the
 *                 given rule to the given nodes.
 *
 * @param {object} rule  rule definition
 * @param {object} nodes nodes on which copy the attribute
 */
function copyAttribute(configurationRule, nodes) {
    const rule = configurationRule;
    for (const attribute of rule.attributes) {
        const oldAttributeName = Object.keys(attribute)[0];
        const newAttributeName = attribute[oldAttributeName];
        nodes.forEach((node) => {
            const attr = node.attr(oldAttributeName);
            if (!attr) {
                console.log(`[${chalk_1.default.yellow("WARNING")}] ${oldAttributeName} was not found, ignoring…`);
                return;
            }
            const value = attr.value();
            node.attr({ [newAttributeName]: value });
        });
    }
}
exports.copyAttribute = copyAttribute;
//# sourceMappingURL=copyAttribute.js.map