"use strict";
/**
 * @fileoverview Rename an attribute
 * @author Frédéric Maquin <fred@ephread.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------
/**
 * renameAttribute - Rename an attribute name specified by the given rule to the given nodes.
 *
 * @param {object} rule  rule definition
 * @param {object} nodes nodes on which remove attributes
 */
function renameAttribute(configurationRule, nodes) {
    const rule = configurationRule;
    for (const attribute of rule.attributes) {
        const oldAttributeName = Object.keys(attribute)[0];
        const newAttributeName = attribute[oldAttributeName];
        nodes.forEach((node) => {
            const attr = node.attr(oldAttributeName);
            if (!attr) {
                console.log(`[${chalk_1.default.yellow("WARNING")}] ${oldAttributeName} was not found, ignoring…`);
                return;
            }
            const value = attr.value();
            node.attr({ [newAttributeName]: value });
            attr.remove();
        });
    }
}
exports.renameAttribute = renameAttribute;
//# sourceMappingURL=renameAttribute.js.map