"use strict";
/**
 * @fileoverview Sophisticate the SVG files.
 * @author Frédéric Maquin <fred@ephread.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
// ----------------------------------------------------------------------------
// Requirements
// ----------------------------------------------------------------------------
const chalk_1 = require("chalk");
const FS = require("fs");
const Path = require("path");
const inline_svg_1 = require("./inline-svg");
// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------
/**
 * sophisticateSVG - Sophisticate the SVG files.
 *
 * @param {type} argv parsed command line arguments.
 */
function sophisticateSVG(argv) {
    console.log("Processing files…");
    for (const path of argv._) {
        inline_svg_1.processSVG(path, argv.c).then((result) => {
            const filename = `${argv.c}/sophisticated_${Path.basename(path)}`;
            FS.writeFile(filename, result.data, (err) => {
                if (err) {
                    console.log(`[${chalk_1.default.red("ERROR")}] Couldn't write processed SVG file - ${err.message}`);
                    process.exit(1);
                }
                else {
                    console.log(`${chalk_1.default.green("DONE!")} - Output: ${filename}\n`);
                }
            });
        });
    }
}
exports.sophisticateSVG = sophisticateSVG;
//# sourceMappingURL=svg.js.map